@@ -8,23 +8,23 @@ extends 'API::Stripe::Client';
 use Carp ();
 use Scalar::Util ();
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 has identifier => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     default  => 'API::Stripe (Perl)',
 );
 
 has username => (
     is       => 'rw',
-    isa      => STRING,
+    isa      => Str,
     required => 1,
 );
 
 has version => (
     is       => 'rw',
-    isa      => INTEGER,
+    isa      => Int,
     default  => 1,
 );
 
@@ -124,7 +124,7 @@ API::Stripe - Perl 5 API wrapper for Stripe
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
@@ -373,9 +373,9 @@ used in all HTTP requests. This attribute expects a L<Mojo::UserAgent> object.
 
     # e.g.
 
-    $stripe->action('head', %args);   # HEAD request
-    $stripe->action('optons', %args); # OPTIONS request
-    $stripe->action('patch', %args);  # PATCH request
+    $stripe->action('head', %args);    # HEAD request
+    $stripe->action('options', %args); # OPTIONS request
+    $stripe->action('patch', %args);   # PATCH request
 
 The action method issues a request to the API resource represented by the
 object. The first parameter will be used as the HTTP request method. The
